#ifndef ReadFluka_h
#define ReadFluka_h

///////////////////////////////////////////////////////////////
//
// ReadFluka
//
// base class to read FLUKA binary outputs
//
//////////////////////////////////////////////////////////////

#include <fstream>
#include "ROOT_types.h"
using namespace std;

class ReadFluka {
 private:
  Char_t               *fchar;            // temprorary char
  Char_t               *fRunTitle;        // run title
  Char_t               *fRunTime;         // run time

 protected:
  UInt_t                fVerbose;         // debug mode level
  ifstream              *fin;             //! file descriptor
  Int_t                 fNCASE;           // number of primaries handled so far (current one included)

 public:
  ReadFluka(const char *fname);
  virtual ~ReadFluka();

  Int_t                  ReadInt(Int_t n=1) const;    // read n integers
  Float_t                ReadFloat(Int_t n=1) const;  // read n floats
  Bool_t                 ReadBool(Int_t n = 1) const; // read n bools
  void                   ReadRunTitle();              // read run titie
  void                   ReadRunTime();               // read run time
  Char_t                *GetRunTitle() const {return fRunTitle;}
  Char_t                *GetRunTime() const {return fRunTime;}
  const Int_t            GetEntries() const {return fNCASE;}
  void                   SetVerboseLevel(UInt_t level) {fVerbose = level;}
};

#endif
